@@ -12,8 +12,6 @@ module Win32
     # The error class raised if any task scheduler specific calls fail.
     class Error < Puppet::Util::Windows::Error; end
 
-    private
-
     class << self
       attr_accessor :com_initialized
     end
@@ -92,8 +90,6 @@ module Win32
     # No mapping between account names and security IDs was done.
     ERROR_NONE_MAPPED                     = -2147023564 # 0x80070534  WIN32 Error CODE 1332 (0x534)
 
-    public
-
     # :startdoc:
 
     # Shorthand constants
@@ -919,7 +915,7 @@ module Win32
             if ValidTypeKeys.include?(subkey)
               new_type_hash[subkey] = subvalue
             else
-              raise ArgumentError, "Invalid type key '#{subkey}'"
+              raise ArgumentError, _("Invalid type key '%{key}'") % { key: subkey }
             end
           }
           new_hash[key] = new_type_hash
@@ -927,7 +923,7 @@ module Win32
           if ValidTriggerKeys.include?(key)
             new_hash[key] = value
           else
-            raise ArgumentError, "Invalid key '#{key}'"
+            raise ArgumentError, _("Invalid key '%{key}'") % { key: key }
           end
         end
       }
@@ -935,8 +931,6 @@ module Win32
       new_hash
     end
 
-    private
-
     def reset_current_task
       # Ensure that COM reference is decremented properly
       @pITask.Release if @pITask && ! @pITask.null?
@@ -1052,12 +1046,9 @@ module Win32
 
     module COM
       extend FFI::Library
-      private
 
       com = Puppet::Util::Windows::COM
 
-      public
-
       # https://msdn.microsoft.com/en-us/library/windows/desktop/aa381811(v=vs.85).aspx
       ITaskScheduler = com::Interface[com::IUnknown,
         FFI::WIN32::GUID['148BD527-A2AB-11CE-B11F-00AA00530503'],
